==> fortunes-python-2021.8.7.tar.gz: fortunes-python-2021.8.7/README.md <==
# Installation
pip install [fortunes-python](https://pypi.org/project/fortunes-python/)

# Python fortune data files

## DESCRIPTION
This package contains some [Python](https://www.python.org/) programming language aphorisms and quotes for the [fortune](https://en.wikipedia.org/wiki/Fortune_(Unix)) utility.

If you find other good ones, feel free to submit them in the repository's [discussion](https://github.com/HubTou/fortunes-python/discussions) board or clone the repository and make a pull request.

## FILES
Filename|Sources
---|---
python-philosophy|[PEP 20 -- The Zen of Python](https://www.python.org/dev/peps/pep-0020/)
python-quotes|[The Mind at Work: Guido van Rossum on how Python makes thinking in code easier](https://blog.dropbox.com/topics/work-culture/-the-mind-at-work--guido-van-rossum-on-how-python-makes-thinking) by Anthony Wing Kosner, [Quotes and Sayings About Python](https://www.inspiringquotes.us/topic/6064-python/page:2), [Python Quotes](https://stgray.com/quotes/pythonquotes.html), among others

## SEE ALSO
[fortune(6)](https://www.freebsd.org/cgi/man.cgi?query=fortune&manpath=FreeBSD+14.0-current),
[strfile(8)](https://www.freebsd.org/cgi/man.cgi?query=strfile)

## HISTORY
These data files are intended to be used with the [PNU project](https://github.com/HubTou/PNU)'s re-implementation of the [fortune](https://github.com/HubTou/fortune) comman
d.

## LICENSE
The original materials were fetched from miscellaneous Internet web sites.
PEP20 and many of them are just in the Public Domain.
The [Guido van Rossum](https://en.wikipedia.org/wiki/Guido_van_Rossum) interview might be copyrighted by [DropBox](https://www.dropbox.com/) or its author, Anthony Wing Kosner, though not clearly indicated.

## AUTHORS
[Hubert Tournier](https://github.com/HubTou) for the package.

Many people for the fortune files contents, though the following people stand out:
* [Guido van Rossum](https://en.wikipedia.org/wiki/Guido_van_Rossum)
* [Tim Peters](https://en.wikipedia.org/wiki/Tim_Peters_(software_engineer))

==> fortunes-python-2021.8.8.tar.gz: fortunes-python-2021.8.8/README.md <==
# Installation
pip install [fortunes-python](https://pypi.org/project/fortunes-python/)

# Python fortune data files

## DESCRIPTION
This package contains some [Python](https://www.python.org/) programming language aphorisms and quotes for the [fortune](https://en.wikipedia.org/wiki/Fortune_(Unix)) utility.

If you find other good ones, feel free to submit them in the repository's [discussion](https://github.com/HubTou/fortunes-python/discussions) board or clone the repository and make a pull request.

## FILES
Filename|Sources
---|---
python-philosophy|[PEP 20 -- The Zen of Python](https://www.python.org/dev/peps/pep-0020/)
python-quotes|[The Mind at Work: Guido van Rossum on how Python makes thinking in code easier](https://blog.dropbox.com/topics/work-culture/-the-mind-at-work--guido-van-rossum-on-how-python-makes-thinking) by Anthony Wing Kosner, [Quotes and Sayings About Python](https://www.inspiringquotes.us/topic/6064-python/page:2), [Python Quotes](https://stgray.com/quotes/pythonquotes.html), among others

## SEE ALSO
[fortune(6)](https://www.freebsd.org/cgi/man.cgi?query=fortune&manpath=FreeBSD+14.0-current),
[strfile(8)](https://www.freebsd.org/cgi/man.cgi?query=strfile)

## HISTORY
These data files are intended to be used with the [PNU project](https://github.com/HubTou/PNU)'s re-implementation of the [fortune](https://github.com/HubTou/fortune) command.

## LICENSE
The original materials were fetched from miscellaneous Internet web sites.
PEP20 and many of them are just in the Public Domain.
The [Guido van Rossum](https://en.wikipedia.org/wiki/Guido_van_Rossum) interview might be copyrighted by [DropBox](https://www.dropbox.com/) or its author, Anthony Wing Kosner, though not clearly indicated.

## AUTHORS
[Hubert Tournier](https://github.com/HubTou) for the package.

Many people for the fortune files contents, though the following people stand out:
* [Guido van Rossum](https://en.wikipedia.org/wiki/Guido_van_Rossum)
* [Tim Peters](https://en.wikipedia.org/wiki/Tim_Peters_(software_engineer))
